preambule = r"""

\documentclass[a4paper,12pt]{article}

\usepackage[T2A]{fontenc}
\usepackage[utf8]{inputenc}
\usepackage[english,russian]{babel}
\usepackage[pdftex]{graphicx}
\usepackage{array,tabularx,tabulary,booktabs}
\usepackage{longtable}  

\graphicspath{{images/}}



\usepackage{amsmath,amsfonts,amssymb,amsthm,mathtools} 
"""

term = r"""

\end{document} 
"""

head_end = r'''
\begin{document}

\maketitle'''
